/***************************************************************************
                          qgrid.cpp  -   QGrid
                             -------------------
    begin                : Fri Jan 12 13:46:56 CET 2001
    copyright            : (C) 2001 by Johan Maes - ON1MH
    email                : on1mh@pandora.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include <qaccel.h>
#include "qgridglobal.h"
#include "qlineedit.h"
#include "qgrid.h"
#include "helper.h"
#include "configdialog.h"



QgridApp::QgridApp()
{
  setCaption("QGrid " VERSION);

  ///////////////////////////////////////////////////////////////////
  // call inits to invoke all other construction parts
  initActions();
  initMenuBar();
	initView();
	setMaximumSize(560,290);
}

QgridApp::~QgridApp()
{
}

/** initializes all QActions of the application */
void QgridApp::initActions(){
  fileQuit = new QAction("Exit", "E&xit", QAccel::stringToKey("Ctrl+Q"), this);
  fileQuit->setStatusTip("Quits the application");
  fileQuit->setWhatsThis("Exit\n\nQuits the application");
  connect(fileQuit, SIGNAL(activated()), this, SLOT(slotFileQuit()));

	
  configure = new QAction(tr("Configure"), tr("&Configure"), 0, this);
  configure->setStatusTip(tr("Configuration"));
  configure->setWhatsThis(tr("Configuration\n\nConfiguartion parameters"));
  connect(configure, SIGNAL(activated()), this, SLOT(slotConfigure()));
	
	userGuide = new QAction(tr("QGrid Handbook"), tr("&QGrid Handbook"), QAccel::stringToKey(tr("F1")), this);
  userGuide->setStatusTip(tr("QGrid Handbook"));
  userGuide->setWhatsThis(tr("QGrid Handbook"));
  connect(userGuide, SIGNAL(activated()), this, SLOT(slotUserGuide()));
		
  helpAboutApp = new QAction("About", "&About...", 0, this);
  helpAboutApp->setStatusTip("About the application");
  helpAboutApp->setWhatsThis("About\n\nAbout the application");
  connect(helpAboutApp, SIGNAL(activated()), this, SLOT(slotHelpAbout()));

}

void QgridApp::initMenuBar()
{
  ///////////////////////////////////////////////////////////////////
  // MENUBAR
	fileMenu=new QPopupMenu();	
  fileQuit->addTo(fileMenu);
	optionMenu=new QPopupMenu();
	configure->addTo(optionMenu);


  ///////////////////////////////////////////////////////////////////
  // menuBar entry helpMenu
  helpMenu=new QPopupMenu();
	userGuide->addTo(helpMenu);
	helpAboutApp->addTo(helpMenu);

  ///////////////////////////////////////////////////////////////////
  // MENUBAR CONFIGURATION
  menuBar()->insertItem("&File", fileMenu);
  menuBar()->insertItem("&Options", optionMenu);
  menuBar()->insertSeparator();
  menuBar()->insertItem("&Help", helpMenu);

}




void QgridApp::initView()
{
  ////////////////////////////////////////////////////////////////////
  // set the main widget here
  view=new QgridView(this);
  setCentralWidget(view);
}

bool QgridApp::queryExit()
{
  int exit=QMessageBox::information(this, "Quit...",
                                    "Do your really want to quit?",
                                    QMessageBox::Ok, QMessageBox::Cancel);

 return (exit==1);
}

/////////////////////////////////////////////////////////////////////
// SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////


void QgridApp::slotFileQuit()
{

	if(queryExit())
    {
      confDiag->writeSettings();
      qApp->quit();
    }

}


void QgridApp::slotUserGuide()
{

	QString home=docPath+"/index.html";
	
	
	QFileInfo finfo(home);
	if (finfo.isReadable())
		{
			HelpWindow *help = new HelpWindow(home, ".", 0, "help viewer");	
 			if ( QApplication::desktop()->width() > 400
	 				&& QApplication::desktop()->height() > 500 )
				{
					help->show();
				}
			else
				{
					help->showMaximized();
				}
		}
	else
		{
	QMessageBox::warning(this,"Contents...",
                      "the file:\n" + home + "\nwas not found\n"
                      + "Select the documentation path\n(Help->Helpfile Path) ");		
		}
}


void QgridApp::slotConfigure()
{
	configDialog diag(0,0);
	diag.exec();
}



void QgridApp::slotHelpAbout()
{
  QMessageBox::about(this,"About...",
                      "Qgrid\nVersion " VERSION "\n(c) 2005 by Johan Maes - ON4QZ"
                      "\n e-mail: on4qz@telenet.be" );
}


